==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/content/fluids/pipes/SmartPipeFilterSlot.java <==
package com.zurrtum.create.client.content.fluids.pipes;


import com.zurrtum.create.catnip.math.AngleHelper;
import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.client.flywheel.lib.transform.TransformStack;
import com.zurrtum.create.client.foundation.blockEntity.behaviour.ValueBoxTransform;
import com.zurrtum.create.content.fluids.pipes.SmartFluidPipeBlock;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_2738;
import net.minecraft.class_4587;

public class SmartPipeFilterSlot extends ValueBoxTransform {

    @Override
    public class_243 getLocalOffset(class_2680 state) {
        class_2738 face = state.method_11654(SmartFluidPipeBlock.field_11007);
        float y = face == class_2738.field_12473 ? 0.55f : face == class_2738.field_12471 ? 11.4f : 15.45f;
        float z = face == class_2738.field_12473 ? 4.6f : face == class_2738.field_12471 ? 0.55f : 4.625f;
        return VecHelper.rotateCentered(VecHelper.voxelSpace(8, y, z), angleY(state), class_2351.field_11052);
    }

    @Override
    public float getScale() {
        return super.getScale() * 1.02f;
    }

    @Override
    public void rotate(class_2680 state, class_4587 ms) {
        class_2738 face = state.method_11654(SmartFluidPipeBlock.field_11007);
        TransformStack.of(ms).rotateYDegrees(angleY(state)).rotateXDegrees(face == class_2738.field_12473 ? -45 : 45);
    }

    protected float angleY(class_2680 state) {
        class_2738 face = state.method_11654(SmartFluidPipeBlock.field_11007);
        float horizontalAngle = AngleHelper.horizontalAngle(state.method_11654(SmartFluidPipeBlock.field_11177));
        if (face == class_2738.field_12471)
            horizontalAngle += 180;
        return horizontalAngle;
    }
}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/client/content/fluids/pipes/SmartPipeFilterSlot.java <==
package com.zurrtum.create.client.content.fluids.pipes;


import com.zurrtum.create.catnip.math.AngleHelper;
import com.zurrtum.create.catnip.math.VecHelper;
import com.zurrtum.create.client.flywheel.lib.transform.TransformStack;
import com.zurrtum.create.client.foundation.blockEntity.behaviour.ValueBoxTransform;
import com.zurrtum.create.content.fluids.pipes.SmartFluidPipeBlock;
import net.minecraft.class_1936;
import net.minecraft.class_2338;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_2738;
import net.minecraft.class_4587;

public class SmartPipeFilterSlot extends ValueBoxTransform {

    @Override
    public class_243 getLocalOffset(class_1936 level, class_2338 pos, class_2680 state) {
        class_2738 face = state.method_11654(SmartFluidPipeBlock.field_11007);
        float y = face == class_2738.field_12473 ? 0.55f : face == class_2738.field_12471 ? 11.4f : 15.45f;
        float z = face == class_2738.field_12473 ? 4.6f : face == class_2738.field_12471 ? 0.55f : 4.625f;
        return VecHelper.rotateCentered(VecHelper.voxelSpace(8, y, z), angleY(state), class_2351.field_11052);
    }

    @Override
    public float getScale() {
        return super.getScale() * 1.02f;
    }

    @Override
    public void rotate(class_1936 level, class_2338 pos, class_2680 state, class_4587 ms) {
        class_2738 face = state.method_11654(SmartFluidPipeBlock.field_11007);
        TransformStack.of(ms).rotateYDegrees(angleY(state)).rotateXDegrees(face == class_2738.field_12473 ? -45 : 45);
    }

    protected float angleY(class_2680 state) {
        class_2738 face = state.method_11654(SmartFluidPipeBlock.field_11007);
        float horizontalAngle = AngleHelper.horizontalAngle(state.method_11654(SmartFluidPipeBlock.field_11177));
        if (face == class_2738.field_12471)
            horizontalAngle += 180;
        return horizontalAngle;
    }
}
